# nauta

Línea de comandos para el nauta hogar Cuba

## Instalación con pipx

```bash
pipx install nauta --force
```

## Guía

1. Agregar un usuario

```console
nauta add micorreo@nauta.com.cu contraseña
```

2. Iniciar sesión
```console
nauta login
```

3. Cerrar sesión
```console
nauta logout
```

## Ayuda

```bash
nauta --help
```